==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/BLOCKACTVENDORLIST_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour BLOCKACTVENDORLIST_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="BLOCKACTVENDORLIST_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BLOCKVENDORLIST" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BLOCKACTVENDORLIST_Type", propOrder = {
    "blockvendorlist"
})
public class BLOCKACTVENDORLIST_Type {

    @XmlElement(name = "BLOCKVENDORLIST")
    protected BLOCKVENDORLIST_Type blockvendorlist;

    /**
     * Obtient la valeur de la propriété blockvendorlist.
     * 
     * @return
     *     possible object is
     *     {@link BLOCKVENDORLIST_Type }
     *     
     */
    public BLOCKVENDORLIST_Type getBLOCKVENDORLIST() {
        return blockvendorlist;
    }

    /**
     * Définit la valeur de la propriété blockvendorlist.
     * 
     * @param value
     *     allowed object is
     *     {@link BLOCKVENDORLIST_Type }
     *     
     */
    public void setBLOCKVENDORLIST(BLOCKVENDORLIST_Type value) {
        this.blockvendorlist = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/BLOCKACTVENDORLIST_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BLOCKACTVENDORLIST_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BLOCKACTVENDORLIST_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BLOCKVENDORLIST" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BLOCKACTVENDORLIST_Type", propOrder = {
    "blockvendorlist"
})
public class BLOCKACTVENDORLIST_Type {

    @XmlElement(name = "BLOCKVENDORLIST")
    protected BLOCKVENDORLIST_Type blockvendorlist;

    /**
     * Gets the value of the blockvendorlist property.
     * 
     * @return
     *     possible object is
     *     {@link BLOCKVENDORLIST_Type }
     *     
     */
    public BLOCKVENDORLIST_Type getBLOCKVENDORLIST() {
        return blockvendorlist;
    }

    /**
     * Sets the value of the blockvendorlist property.
     * 
     * @param value
     *     allowed object is
     *     {@link BLOCKVENDORLIST_Type }
     *     
     */
    public void setBLOCKVENDORLIST(BLOCKVENDORLIST_Type value) {
        this.blockvendorlist = value;
    }

}
